@@ -1,6 +1,6 @@
 /* Copyright (C) 2003 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: listcontrol.c,v 1.42 2005/10/09 14:17:52 mmj Exp $
+ * $Id: listcontrol.c,v 1.43 2006/01/04 19:10:24 mmj Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -108,7 +108,8 @@ int listcontrol(struct email_container *fromemails, const char *listdir,
 	const char *subswitch;
 	size_t len;
 	struct stat stbuf;
-	int closedlist, nosubconfirm, tmpfd, noget, i, subonlyget = 0;
+	int closedlist, nosubconfirm, tmpfd, noget, i, closedlistsub,
+	    subonlyget = 0;
 	size_t cmdlen;
 	unsigned int ctrl;
 	struct strlist *owners;
@@ -116,6 +117,9 @@ int listcontrol(struct email_container *fromemails, const char *listdir,
 	/* A closed list doesn't allow subscribtion and unsubscription */
 	closedlist = statctrl(listdir, "closedlist");
 
+	/* A closed list "sub" only dissallows subscription, not unsub. */
+	closedlistsub = statctrl(listdir, "closedlistsub");
+
 	nosubconfirm = statctrl(listdir, "nosubconfirm");
 	if(nosubconfirm)
 		subswitch = "-c";
@@ -183,7 +187,7 @@ int listcontrol(struct email_container *fromemails, const char *listdir,
 	/* listname+subscribe-digest@domain.tld */
 	case CTRL_SUBSCRIBE_DIGEST:
 		unlink(mailname);
-		if (closedlist)
+		if (closedlist || closedlistsub)
 			exit(EXIT_SUCCESS);
 		if (!strchr(fromemails->emaillist[0], '@'))
 			/* Not a valid From: address, silently ignore */
@@ -204,7 +208,7 @@ int listcontrol(struct email_container *fromemails, const char *listdir,
 	/* listname+subscribe-nomail@domain.tld */
 	case CTRL_SUBSCRIBE_NOMAIL:
 		unlink(mailname);
-		if (closedlist)
+		if (closedlist || closedlistsub)
 			exit(EXIT_SUCCESS);
 		if (!strchr(fromemails->emaillist[0], '@'))
 			/* Not a valid From: address, silently ignore */
@@ -225,7 +229,7 @@ int listcontrol(struct email_container *fromemails, const char *listdir,
 	/* listname+subscribe@domain.tld */
 	case CTRL_SUBSCRIBE:
 		unlink(mailname);
-		if (closedlist)
+		if (closedlist || closedlistsub)
 			exit(EXIT_SUCCESS);
 		if (!strchr(fromemails->emaillist[0], '@'))
 			/* Not a valid From: address, silently ignore */
