@@ -1,6 +1,6 @@
 /* Copyright (C) 2003, 2003, 2004 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: mlmmj-process.c,v 1.70 2005/11/15 21:46:52 mmj Exp $
+ * $Id: mlmmj-process.c,v 1.74 2006/01/18 23:37:58 mortenp Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -562,6 +562,7 @@ int main(int argc, char **argv)
 					efromemails.emaillist[0]);
 			execlp(mlmmjsend, mlmmjsend,
 					"-l", "4",
+					"-L", listdir,
 					"-F", efromemails.emaillist[0],
 					"-s", owner,
 					"-a",
@@ -582,8 +583,16 @@ int main(int argc, char **argv)
 
 	/* discard malformed mail with invalid From: */
 	if(fromemails.emailcount != 1) { 
+		for(i = 0; i < fromemails.emailcount; i++)
+			printf("fromemails.emaillist[%d] = %s\n",
+					i, fromemails.emaillist[i]);
 		discardname = concatstr(3, listdir,
 				"/queue/discarded/", randomstr);
+		log_error(LOG_ARGS, "Discarding %s due to invalid From:",
+				mailfile);
+		for(i = 0; i < fromemails.emailcount; i++)
+			log_error(LOG_ARGS, "fromemails.emaillist[%d] = %s\n",
+					i, fromemails.emaillist[i]);
 		rename(mailfile, discardname);
 		unlink(donemailname);
 		myfree(donemailname);
@@ -600,6 +609,9 @@ int main(int argc, char **argv)
 		discardname = concatstr(3, listdir,
 				"/queue/discarded/",
 				randomstr);
+		log_error(LOG_ARGS, "Discarding %s due to invalid envelope"
+				" from email count (was %d, must be 1)",
+				mailfile, efromemails.emailcount);
 		rename(mailfile, discardname);
 		unlink(donemailname);
 		myfree(donemailname);
@@ -645,6 +657,11 @@ int main(int argc, char **argv)
 		 */
 		if ((strcasecmp(listaddr, fromemails.emaillist[0]) == 0) ||
 				notoccdenymails) {
+			log_error(LOG_ARGS, "Discarding %s because list"
+					" address was not in To: or Cc:,"
+					" and From: was the list or"
+					" notoccdenymails was set",
+					mailfile);
 			myfree(listaddr);
 			unlink(donemailname);
 			myfree(donemailname);
@@ -666,6 +683,7 @@ int main(int argc, char **argv)
 		myfree(donemailname);
 		execlp(mlmmjsend, mlmmjsend,
 				"-l", "1",
+				"-L", listdir,
 				"-T", fromemails.emaillist[0],
 				"-F", fromaddr,
 				"-m", queuefilename, (char *)NULL);
@@ -681,6 +699,10 @@ int main(int argc, char **argv)
 		/* Don't send a mail about denial to the list, but silently
 		 * discard and exit. */
 		if (strcasecmp(listaddr, fromemails.emaillist[0]) == 0) {
+			log_error(LOG_ARGS, "Discarding %s because"
+					" subonlypost was set and From: was"
+					" the list address",
+					mailfile);
 			myfree(listaddr);
 			unlink(donemailname);
 			myfree(donemailname);
@@ -688,6 +710,10 @@ int main(int argc, char **argv)
 		}
 		if(is_subbed(listdir, fromemails.emaillist[0]) != 0) {
 			if(nosubonlydenymails) {
+				log_error(LOG_ARGS, "Discarding %s because"
+						" subonlypost and"
+						" nosubonlydenymails was set",
+						mailfile);
 				myfree(listaddr);
 				unlink(donemailname);
 				myfree(donemailname);
@@ -731,6 +757,12 @@ int main(int argc, char **argv)
 		if (accret == DENY) {
 			if ((strcasecmp(listaddr, fromemails.emaillist[0]) ==
 						0) || noaccessdenymails) {
+				log_error(LOG_ARGS, "Discarding %s because"
+						" it was denied by an access"
+						" rule, and From: was the list"
+						" address or noaccessdenymails"
+						" was set",
+						mailfile);
 				myfree(listaddr);
 				unlink(donemailname);
 				myfree(donemailname);
@@ -755,6 +787,7 @@ int main(int argc, char **argv)
 			myfree(randomstr);
 			execlp(mlmmjsend, mlmmjsend,
 					"-l", "1",
+					"-L", listdir,
 					"-T", fromemails.emaillist[0],
 					"-F", fromaddr,
 					"-m", queuefilename, (char *)NULL);
